.. lstmcpipe documentation master file, created by
   sphinx-quickstart on Thu Dec 16 09:27:21 2021.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.


.. include:: ../README.rst

.. include:: ../CONTRIBUTING.rst

.. toctree::
   :maxdepth: 3

   lstmcpipe_user_doc.md
   productions
   pipeline
   examples/configs_pointings
   cli
   api/lstmcpipe


